==> react-image-annotate_ns_demo-5.0.11.tgz: package/Annotator/index.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

import React, { useEffect, useMemo, useReducer, useState } from "react";
import makeImmutable, { without } from "seamless-immutable";
import useEventCallback from "use-event-callback";
import { textractObjects } from "../box_interction";
import MainLayout from "../MainLayout";
import SettingsProvider from "../SettingsProvider";
import getFromLocalStorage from "../utils/get-from-local-storage";
import combineReducers from "./reducers/combine-reducers.js";
import generalReducer from "./reducers/general-reducer.js";
import historyHandler from "./reducers/history-handler.js";
import imageReducer from "./reducers/image-reducer.js";
import videoReducer from "./reducers/video-reducer.js";
window.undoArray = [];
window.annotation_redo = [];
window.AnnoationRedo = [];
export var Annotator = function Annotator(_ref) {
  var images = _ref.images,
      allowedArea = _ref.allowedArea,
      _ref$selectedImage = _ref.selectedImage,
      selectedImage = _ref$selectedImage === void 0 ? images && images.length > 0 ? 0 : undefined : _ref$selectedImage,
      showPointDistances = _ref.showPointDistances,
      pointDistancePrecision = _ref.pointDistancePrecision,
      _ref$showTags = _ref.showTags,
      showTags = _ref$showTags === void 0 ? getFromLocalStorage("showTags", true) : _ref$showTags,
      _ref$enabledTools = _ref.enabledTools,
      enabledTools = _ref$enabledTools === void 0 ? ["select", "create-point", "create-box", "create-a-brush", "create-polygon", "create-line", "create-expanding-line", "show-mask"] : _ref$enabledTools,
      _ref$selectedTool = _ref.selectedTool,
      selectedTool = _ref$selectedTool === void 0 ? "select" : _ref$selectedTool,
      _ref$regionTagList = _ref.regionTagList,
      regionTagList = _ref$regionTagList === void 0 ? [] : _ref$regionTagList,
      _ref$regionClsList = _ref.regionClsList,
      regionClsList = _ref$regionClsList === void 0 ? [] : _ref$regionClsList,
      _ref$imageTagList = _ref.imageTagList,
      imageTagList = _ref$imageTagList === void 0 ? [] : _ref$imageTagList,
      _ref$imageClsList = _ref.imageClsList,
      imageClsList = _ref$imageClsList === void 0 ? [] : _ref$imageClsList,
      _ref$keyframes = _ref.keyframes,
      keyframes = _ref$keyframes === void 0 ? {} : _ref$keyframes,
      _ref$taskDescription = _ref.taskDescription,
      taskDescription = _ref$taskDescription === void 0 ? "" : _ref$taskDescription,
      _ref$fullImageSegment = _ref.fullImageSegmentationMode,
      fullImageSegmentationMode = _ref$fullImageSegment === void 0 ? false : _ref$fullImageSegment,
      RegionEditLabel = _ref.RegionEditLabel,
      videoSrc = _ref.videoSrc,
      _ref$videoTime = _ref.videoTime,
      videoTime = _ref$videoTime === void 0 ? 0 : _ref$videoTime,
      videoName = _ref.videoName,
      onExit = _ref.onExit,
      onNextImage = _ref.onNextImage,
      onPrevImage = _ref.onPrevImage,
      keypointDefinitions = _ref.keypointDefinitions,
      _ref$autoSegmentation = _ref.autoSegmentationOptions,
      autoSegmentationOptions = _ref$autoSegmentation === void 0 ? {
    type: "autoseg"
  } : _ref$autoSegmentation,
      hideHeader = _ref.hideHeader,
      hideHeaderText = _ref.hideHeaderText,
      hideNext = _ref.hideNext,
      hidePrev = _ref.hidePrev,
      hideClone = _ref.hideClone,
      hideSettings = _ref.hideSettings,
      hideFullScreen = _ref.hideFullScreen,
      hideSave = _ref.hideSave,
      allowComments = _ref.allowComments,
      onAddQuery = _ref.onAddQuery,
      saveandnext = _ref.saveandnext,
      _ref$issavenextDisabl = _ref.issavenextDisabled,
      issavenextDisabled = _ref$issavenextDisabl === void 0 ? false : _ref$issavenextDisabl,
      _ref$isaddQueryDisabl = _ref.isaddQueryDisabled,
      isaddQueryDisabled = _ref$isaddQueryDisabl === void 0 ? false : _ref$isaddQueryDisabl,
      _ref$isSubmitDisabled = _ref.isSubmitDisabled,
      isSubmitDisabled = _ref$isSubmitDisabled === void 0 ? false : _ref$isSubmitDisabled,
      _ref$lazyBrush = _ref.lazyBrush,
      lazyBrush = _ref$lazyBrush === void 0 ? [] : _ref$lazyBrush,
      xPosition = _ref.xPosition,
      yPosition = _ref.yPosition,
      invaild_show = _ref.invaild_show,
      hideQuery = _ref.hideQuery,
      hideSaveNext = _ref.hideSaveNext,
      _ref$showUpdate = _ref.showUpdate,
      showUpdate = _ref$showUpdate === void 0 ? false : _ref$showUpdate,
      _ref$rightMenu = _ref.rightMenu,
      rightMenu = _ref$rightMenu === void 0 ? true : _ref$rightMenu,
      _ref$isReadingMode = _ref.isReadingMode,
      isReadingMode = _ref$isReadingMode === void 0 ? false : _ref$isReadingMode,
      _ref$brushHighlighted = _ref.brushHighlighted,
      brushHighlighted = _ref$brushHighlighted === void 0 ? -1 : _ref$brushHighlighted,
      isImageMode = _ref.isImageMode,
      blocks = _ref.blocks,
      handleSubmit = _ref.handleSubmit;

  if (typeof selectedImage === "string") {
    selectedImage = (images || []).findIndex(function (img) {
      return img.src === selectedImage;
    });
    if (selectedImage === -1) selectedImage = undefined;
  }

  var annotationType = images ? "image" : "video";

  var _useState = useState(new Map()),
      _useState2 = _slicedToArray(_useState, 2),
      orcTxt = _useState2[0],
      setORCTxt = _useState2[1];

  var _useReducer = useReducer(historyHandler(combineReducers(annotationType === "image" ? imageReducer : videoReducer, generalReducer)), makeImmutable(_objectSpread({
    annotationType: annotationType,
    showTags: showTags,
    allowedArea: allowedArea,
    showPointDistances: showPointDistances,
    pointDistancePrecision: pointDistancePrecision,
    selectedTool: selectedTool,
    fullImageSegmentationMode: fullImageSegmentationMode,
    autoSegmentationOptions: autoSegmentationOptions,
    mode: null,
    taskDescription: taskDescription,
    showMask: true,
    labelImages: imageClsList.length > 0 || imageTagList.length > 0,
    regionClsList: regionClsList,
    regionTagList: regionTagList,
    imageClsList: imageClsList,
    imageTagList: imageTagList,
    currentVideoTime: videoTime,
    enabledTools: enabledTools,
    history: [],
    videoName: videoName,
    keypointDefinitions: keypointDefinitions,
    allowComments: allowComments,
    brushHighlighted: brushHighlighted
  }, annotationType === "image" ? {
    selectedImage: selectedImage,
    images: images,
    selectedImageFrameTime: images && images.length > 0 ? images[0].frameTime : undefined
  } : {
    videoSrc: videoSrc,
    keyframes: keyframes
  } || {}, {
    qc_label: invaild_show
  }))),
      _useReducer2 = _slicedToArray(_useReducer, 2),
      state = _useReducer2[0],
      dispatchToReducer = _useReducer2[1];

  window.textractList = textractObjects(blocks); // call textract and parse response

  window.onChangeOCR = function (index, label, value) {
    var a1 = new Map(orcTxt);

    if (label === "delete") {
      a1.delete(index);
    } else {
      a1.set(index, _objectSpread({}, a1.get(index), _defineProperty({}, label, value)));
    }

    setORCTxt(a1);
  };

  var _React$useState = React.useState([]),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      lines = _React$useState2[0],
      setLines = _React$useState2[1];

  var _useState3 = useState([]),
      _useState4 = _slicedToArray(_useState3, 2),
      delete_annotation = _useState4[0],
      setdelete_annotation = _useState4[1];

  var dispatch = useEventCallback(function (action) {
    if (action.type === "HEADER_BUTTON_CLICKED") {
      if (["Exit", "Done", "Save", "Complete", "Submit", "Update"].includes(action.buttonName)) {
        return onExit(without({
          annotation: state,
          lazyBrush: lines,
          delete_annotation: delete_annotation
        }, "history"));
      } else if (action.buttonName === "Next" && onNextImage) {
        return onNextImage(without(state, "history"));
      } else if (action.buttonName === "Prev" && onPrevImage) {
        return onPrevImage(without(state, "history"));
      } else if (action.buttonName === "Add Query" && onAddQuery) {
        return onAddQuery(without(state, "history"));
      } else if (action.buttonName === "Save & next" && saveandnext) {
        return saveandnext(without({
          annotation: state,
          lazyBrush: lines,
          delete_annotation: delete_annotation
        }, "history"));
      }
    }

    dispatchToReducer(action);
  });
  var layoutORC = useMemo(function () {
    var array = [];

    var _iterator = _createForOfIteratorHelper(orcTxt),
        _step;

    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var _ref4 = _step.value;

        var _ref3 = _slicedToArray(_ref4, 2);

        var key = _ref3[0];
        var value = _ref3[1];
        array.push({
          key: key,
          value: value
        });
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }

    return array;
  }, [orcTxt]);
  var onRegionClassAdded = useEventCallback(function (cls) {
    dispatchToReducer({
      type: "ON_CLS_ADDED",
      cls: cls
    });
  });
  React.useEffect(function () {
    setLines(lazyBrush);
  }, []);

  window.undoBrush = function () {
    var intial_lines = lines.slice(0, -1);
    var obj = {
      brush: lines[lines.length - 1]
    };

    var newArr = _toConsumableArray(window.annotation_redo);

    newArr.push(obj);
    window.annotation_redo = newArr;
    return setLines(intial_lines);
  };

  window.hendleBrush_redo = function () {
    var newArr = _toConsumableArray(window.annotation_redo) || [];

    if (newArr.length) {
      var lastElement = newArr[newArr.length - 1].brush;
      var intial_lines = [].concat(_toConsumableArray(lines), [lastElement]);
      newArr.splice(window.annotation_redo.length - 1, 1);
      window.annotation_redo = newArr;
      window.undoArray = [].concat(_toConsumableArray(window.undoArray), ["brush"]);
      return setLines(intial_lines);
    }
  };

  window.handleBrush_delete = function () {
    var newArr = _toConsumableArray(window.annotation_redo) || [];

    if (newArr.length) {
      var lastElement = newArr[newArr.length - 1].brush;
      var intial_lines = [].concat(_toConsumableArray(lines), _toConsumableArray(lastElement));
      newArr.splice(window.annotation_redo.length - 1, 1);
      window.annotation_redo = newArr;
      window.undoArray = [].concat(_toConsumableArray(window.undoArray), ["brush"]);
      return setLines(intial_lines);
    }
  };

  window.hendleAnnotation_redo = function () {
    dispatch({
      type: "REDO_HISTORY"
    });
  };

  useEffect(function () {
    if (selectedImage === undefined) return;
    dispatchToReducer({
      type: "SELECT_IMAGE",
      imageIndex: selectedImage,
      image: state.images[selectedImage]
    });
  }, [selectedImage, state.images]);
  if (!images && !videoSrc) return 'Missing required prop "images" or "videoSrc"';
  return /*#__PURE__*/React.createElement(SettingsProvider, null, /*#__PURE__*/React.createElement(MainLayout, {
    RegionEditLabel: RegionEditLabel,
    alwaysShowNextButton: Boolean(onNextImage),
    alwaysShowPrevButton: Boolean(onPrevImage),
    state: state,
    dispatch: dispatch,
    onRegionClassAdded: onRegionClassAdded,
    hideHeader: hideHeader,
    hideHeaderText: hideHeaderText,
    hideNext: hideNext,
    hidePrev: hidePrev,
    hideClone: hideClone,
    hideSettings: hideSettings,
    hideFullScreen: hideFullScreen,
    hideSave: hideSave,
    issavenextDisabled: issavenextDisabled,
    isaddQueryDisabled: isaddQueryDisabled,
    isSubmitDisabled: isSubmitDisabled,
    lazyBrush: lazyBrush,
    lazyBrushTags: regionTagList,
    lazyBrushClassification: regionClsList,
    xPosition: xPosition,
    yPosition: yPosition,
    lines: lines,
    setLines: setLines,
    invaild_show: invaild_show,
    setdelete_annotation: setdelete_annotation,
    delete_annotation: delete_annotation,
    hideSaveNext: hideSaveNext,
    hideQuery: hideQuery,
    showUpdate: showUpdate,
    rightMenu: rightMenu,
    isReadingMode: isReadingMode,
    isImageMode: isImageMode,
    layoutORC: layoutORC,
    onChangeLayoutORC: function onChangeLayoutORC(e, key) {
      var a2 = new Map(orcTxt);
      a2.set(key, _objectSpread({}, a2.get(key), {
        value: e.target.value
      }));
      setORCTxt(a2);
    },
    handleSubmit: handleSubmit
  }));
};
export default Annotator;

==> react-image-annotate_ns_demo-5.0.15.tgz: package/Annotator/index.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

import React, { useEffect, useMemo, useReducer, useState } from "react";
import makeImmutable, { without } from "seamless-immutable";
import useEventCallback from "use-event-callback";
import { textractObjects } from "../box_interction";
import MainLayout from "../MainLayout";
import SettingsProvider from "../SettingsProvider";
import getFromLocalStorage from "../utils/get-from-local-storage";
import combineReducers from "./reducers/combine-reducers.js";
import generalReducer from "./reducers/general-reducer.js";
import historyHandler from "./reducers/history-handler.js";
import imageReducer from "./reducers/image-reducer.js";
import videoReducer from "./reducers/video-reducer.js";
window.undoArray = [];
window.annotation_redo = [];
window.AnnoationRedo = [];
export var Annotator = function Annotator(_ref) {
  var images = _ref.images,
      allowedArea = _ref.allowedArea,
      _ref$selectedImage = _ref.selectedImage,
      selectedImage = _ref$selectedImage === void 0 ? images && images.length > 0 ? 0 : undefined : _ref$selectedImage,
      showPointDistances = _ref.showPointDistances,
      pointDistancePrecision = _ref.pointDistancePrecision,
      _ref$showTags = _ref.showTags,
      showTags = _ref$showTags === void 0 ? getFromLocalStorage("showTags", true) : _ref$showTags,
      _ref$enabledTools = _ref.enabledTools,
      enabledTools = _ref$enabledTools === void 0 ? ["select", "create-point", "create-box", "create-a-brush", "create-polygon", "create-line", "create-expanding-line", "show-mask"] : _ref$enabledTools,
      _ref$selectedTool = _ref.selectedTool,
      selectedTool = _ref$selectedTool === void 0 ? "select" : _ref$selectedTool,
      _ref$regionTagList = _ref.regionTagList,
      regionTagList = _ref$regionTagList === void 0 ? [] : _ref$regionTagList,
      _ref$regionClsList = _ref.regionClsList,
      regionClsList = _ref$regionClsList === void 0 ? [] : _ref$regionClsList,
      _ref$imageTagList = _ref.imageTagList,
      imageTagList = _ref$imageTagList === void 0 ? [] : _ref$imageTagList,
      _ref$imageClsList = _ref.imageClsList,
      imageClsList = _ref$imageClsList === void 0 ? [] : _ref$imageClsList,
      _ref$keyframes = _ref.keyframes,
      keyframes = _ref$keyframes === void 0 ? {} : _ref$keyframes,
      _ref$taskDescription = _ref.taskDescription,
      taskDescription = _ref$taskDescription === void 0 ? "" : _ref$taskDescription,
      _ref$fullImageSegment = _ref.fullImageSegmentationMode,
      fullImageSegmentationMode = _ref$fullImageSegment === void 0 ? false : _ref$fullImageSegment,
      RegionEditLabel = _ref.RegionEditLabel,
      videoSrc = _ref.videoSrc,
      _ref$videoTime = _ref.videoTime,
      videoTime = _ref$videoTime === void 0 ? 0 : _ref$videoTime,
      videoName = _ref.videoName,
      onExit = _ref.onExit,
      onNextImage = _ref.onNextImage,
      onPrevImage = _ref.onPrevImage,
      keypointDefinitions = _ref.keypointDefinitions,
      _ref$autoSegmentation = _ref.autoSegmentationOptions,
      autoSegmentationOptions = _ref$autoSegmentation === void 0 ? {
    type: "autoseg"
  } : _ref$autoSegmentation,
      hideHeader = _ref.hideHeader,
      hideHeaderText = _ref.hideHeaderText,
      hideNext = _ref.hideNext,
      hidePrev = _ref.hidePrev,
      hideClone = _ref.hideClone,
      hideSettings = _ref.hideSettings,
      hideFullScreen = _ref.hideFullScreen,
      hideSave = _ref.hideSave,
      allowComments = _ref.allowComments,
      onAddQuery = _ref.onAddQuery,
      saveandnext = _ref.saveandnext,
      _ref$issavenextDisabl = _ref.issavenextDisabled,
      issavenextDisabled = _ref$issavenextDisabl === void 0 ? false : _ref$issavenextDisabl,
      _ref$isaddQueryDisabl = _ref.isaddQueryDisabled,
      isaddQueryDisabled = _ref$isaddQueryDisabl === void 0 ? false : _ref$isaddQueryDisabl,
      _ref$isSubmitDisabled = _ref.isSubmitDisabled,
      isSubmitDisabled = _ref$isSubmitDisabled === void 0 ? false : _ref$isSubmitDisabled,
      _ref$lazyBrush = _ref.lazyBrush,
      lazyBrush = _ref$lazyBrush === void 0 ? [] : _ref$lazyBrush,
      xPosition = _ref.xPosition,
      yPosition = _ref.yPosition,
      invaild_show = _ref.invaild_show,
      hideQuery = _ref.hideQuery,
      hideSaveNext = _ref.hideSaveNext,
      _ref$showUpdate = _ref.showUpdate,
      showUpdate = _ref$showUpdate === void 0 ? false : _ref$showUpdate,
      _ref$rightMenu = _ref.rightMenu,
      rightMenu = _ref$rightMenu === void 0 ? true : _ref$rightMenu,
      _ref$isReadingMode = _ref.isReadingMode,
      isReadingMode = _ref$isReadingMode === void 0 ? false : _ref$isReadingMode,
      _ref$brushHighlighted = _ref.brushHighlighted,
      brushHighlighted = _ref$brushHighlighted === void 0 ? -1 : _ref$brushHighlighted,
      isImageMode = _ref.isImageMode,
      blocks = _ref.blocks,
      handleSubmit = _ref.handleSubmit,
      tilte_key = _ref.tilte_key,
      deleteAnnotationAllow = _ref.deleteAnnotationAllow;

  if (typeof selectedImage === "string") {
    selectedImage = (images || []).findIndex(function (img) {
      return img.src === selectedImage;
    });
    if (selectedImage === -1) selectedImage = undefined;
  }

  var annotationType = images ? "image" : "video";

  var _useState = useState(new Map()),
      _useState2 = _slicedToArray(_useState, 2),
      orcTxt = _useState2[0],
      setORCTxt = _useState2[1];

  var _useReducer = useReducer(historyHandler(combineReducers(annotationType === "image" ? imageReducer : videoReducer, generalReducer)), makeImmutable(_objectSpread({
    annotationType: annotationType,
    showTags: showTags,
    allowedArea: allowedArea,
    showPointDistances: showPointDistances,
    pointDistancePrecision: pointDistancePrecision,
    selectedTool: selectedTool,
    fullImageSegmentationMode: fullImageSegmentationMode,
    autoSegmentationOptions: autoSegmentationOptions,
    mode: null,
    taskDescription: taskDescription,
    showMask: true,
    labelImages: imageClsList.length > 0 || imageTagList.length > 0,
    regionClsList: regionClsList,
    regionTagList: regionTagList,
    imageClsList: imageClsList,
    imageTagList: imageTagList,
    currentVideoTime: videoTime,
    enabledTools: enabledTools,
    history: [],
    videoName: videoName,
    keypointDefinitions: keypointDefinitions,
    allowComments: allowComments,
    brushHighlighted: brushHighlighted
  }, annotationType === "image" ? {
    selectedImage: selectedImage,
    images: images,
    selectedImageFrameTime: images && images.length > 0 ? images[0].frameTime : undefined
  } : {
    videoSrc: videoSrc,
    keyframes: keyframes
  } || {}, {
    qc_label: invaild_show
  }))),
      _useReducer2 = _slicedToArray(_useReducer, 2),
      state = _useReducer2[0],
      dispatchToReducer = _useReducer2[1];

  window.textractList = textractObjects(blocks); // call textract and parse response

  window.onChangeOCR = function (index, label, value) {
    var a1 = new Map(orcTxt);

    if (label === "delete") {
      a1.delete(index);
    } else {
      a1.set(index, _objectSpread({}, a1.get(index), _defineProperty({}, label, value)));
    }

    setORCTxt(a1);
  };

  var _React$useState = React.useState([]),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      lines = _React$useState2[0],
      setLines = _React$useState2[1];

  var _useState3 = useState([]),
      _useState4 = _slicedToArray(_useState3, 2),
      delete_annotation = _useState4[0],
      setdelete_annotation = _useState4[1];

  var dispatch = useEventCallback(function (action) {
    if (action.type === "HEADER_BUTTON_CLICKED") {
      if (["Exit", "Done", "Save", "Complete", "Submit", "Update"].includes(action.buttonName)) {
        return onExit(without({
          annotation: state,
          lazyBrush: lines,
          delete_annotation: delete_annotation
        }, "history"));
      } else if (action.buttonName === "Next" && onNextImage) {
        return onNextImage(without(state, "history"));
      } else if (action.buttonName === "Prev" && onPrevImage) {
        return onPrevImage(without(state, "history"));
      } else if (action.buttonName === "Add Query" && onAddQuery) {
        return onAddQuery(without(state, "history"));
      } else if (action.buttonName === "Save & next" && saveandnext) {
        return saveandnext(without({
          annotation: state,
          lazyBrush: lines,
          delete_annotation: delete_annotation
        }, "history"));
      }
    }

    dispatchToReducer(action);
  });
  var layoutORC = useMemo(function () {
    var array = [];

    var _iterator = _createForOfIteratorHelper(orcTxt),
        _step;

    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var _ref4 = _step.value;

        var _ref3 = _slicedToArray(_ref4, 2);

        var key = _ref3[0];
        var value = _ref3[1];
        array.push({
          key: key,
          value: value
        });
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }

    return array;
  }, [orcTxt]);
  var onRegionClassAdded = useEventCallback(function (cls) {
    dispatchToReducer({
      type: "ON_CLS_ADDED",
      cls: cls
    });
  });
  React.useEffect(function () {
    setLines(lazyBrush);
  }, []);

  window.undoBrush = function () {
    var intial_lines = lines.slice(0, -1);
    var obj = {
      brush: lines[lines.length - 1]
    };

    var newArr = _toConsumableArray(window.annotation_redo);

    newArr.push(obj);
    window.annotation_redo = newArr;
    return setLines(intial_lines);
  };

  window.hendleBrush_redo = function () {
    var newArr = _toConsumableArray(window.annotation_redo) || [];

    if (newArr.length) {
      var lastElement = newArr[newArr.length - 1].brush;
      var intial_lines = [].concat(_toConsumableArray(lines), [lastElement]);
      newArr.splice(window.annotation_redo.length - 1, 1);
      window.annotation_redo = newArr;
      window.undoArray = [].concat(_toConsumableArray(window.undoArray), ["brush"]);
      return setLines(intial_lines);
    }
  };

  window.handleBrush_delete = function () {
    var newArr = _toConsumableArray(window.annotation_redo) || [];

    if (newArr.length) {
      var lastElement = newArr[newArr.length - 1].brush;
      var intial_lines = [].concat(_toConsumableArray(lines), _toConsumableArray(lastElement));
      newArr.splice(window.annotation_redo.length - 1, 1);
      window.annotation_redo = newArr;
      window.undoArray = [].concat(_toConsumableArray(window.undoArray), ["brush"]);
      return setLines(intial_lines);
    }
  };

  window.hendleAnnotation_redo = function () {
    dispatch({
      type: "REDO_HISTORY"
    });
  };

  useEffect(function () {
    if (selectedImage === undefined) return;
    dispatchToReducer({
      type: "SELECT_IMAGE",
      imageIndex: selectedImage,
      image: state.images[selectedImage]
    });
  }, [selectedImage, state.images]);
  if (!images && !videoSrc) return 'Missing required prop "images" or "videoSrc"';
  return /*#__PURE__*/React.createElement(SettingsProvider, null, /*#__PURE__*/React.createElement(MainLayout, {
    RegionEditLabel: RegionEditLabel,
    alwaysShowNextButton: Boolean(onNextImage),
    alwaysShowPrevButton: Boolean(onPrevImage),
    state: state,
    dispatch: dispatch,
    onRegionClassAdded: onRegionClassAdded,
    hideHeader: hideHeader,
    hideHeaderText: hideHeaderText,
    hideNext: hideNext,
    hidePrev: hidePrev,
    hideClone: hideClone,
    hideSettings: hideSettings,
    hideFullScreen: hideFullScreen,
    hideSave: hideSave,
    issavenextDisabled: issavenextDisabled,
    isaddQueryDisabled: isaddQueryDisabled,
    isSubmitDisabled: isSubmitDisabled,
    lazyBrush: lazyBrush,
    lazyBrushTags: regionTagList,
    lazyBrushClassification: regionClsList,
    xPosition: xPosition,
    yPosition: yPosition,
    lines: lines,
    setLines: setLines,
    invaild_show: invaild_show,
    setdelete_annotation: setdelete_annotation,
    delete_annotation: delete_annotation,
    hideSaveNext: hideSaveNext,
    hideQuery: hideQuery,
    showUpdate: showUpdate,
    rightMenu: rightMenu,
    isReadingMode: isReadingMode,
    isImageMode: isImageMode,
    layoutORC: layoutORC,
    onChangeLayoutORC: function onChangeLayoutORC(e, key) {
      var a2 = new Map(orcTxt);
      a2.set(key, _objectSpread({}, a2.get(key), {
        value: e.target.value
      }));
      setORCTxt(a2);
    },
    handleSubmit: handleSubmit,
    tilte_key: tilte_key,
    deleteAnnotationAllow: deleteAnnotationAllow
  }));
};
export default Annotator;
